Comprendre les cookies
Description: Vous souhaitez en savoir plus sur les cookies ? Cette foire aux questions vous aidera à en apprendre davantage sur leurs spécificités.

Les cookies | A quoi servent-ils ? | Solidarité Numérique

Nous utilisons des cookies anonymisés afin de vous offrir la meilleure expérience sur notre site.
Pour en savoir plus sur l’utilisation de nos cookies, vous pouvez consulter notre Politique de confidentialité.

Fermer Politique de confidentialité

Le numéro d'appel n'est pas accessible aujourd'hui. Veuillez nous excuser pour la gêne occasionnée.

Le numéro d'appel n'est pas accessible aujourd'hui. Veuillez nous excuser pour la gêne occasionnée.

#### Sommaire

RéduireAgrandir

- À quoi sert un cookie ?
- Que dit la loi sur l'utilisation des cookies ?
- Puis-je paramétrer ou bloquer l'utilisation des cookies ?

##### Comprendre les cookies

Dernière modification : 17 septembre 2021

Partager
Enregistrer / ImprimerEnregistrer

Vous souhaitez en savoir plus sur les cookies ? Cette foire aux questions vous aidera à comprendre et à en apprendre davantage sur leurs spécificités.

Tags : #Confidentialité #Cookies #DonnéesDeNavigation #DonnéesPersonnelles #RGPD

### Prérequis

- Maîtriser la navigation sur Internet

#####

Les cookies sont des petits fichiers informatiques déposés par le site Internet que vous visitez. Il s'installe sur votre ordinateur, tablette ou smartphone par le navigateur web.

##### Questions - réponses

## À quoi sert un cookie ?

4 types de cookies les plus courants :

- Nécessaires : pour le bon fonctionnement du site Internet. Ils conservent des données pour simplifier votre navigation. Par exemple, les sites les utilisent pour mémoriser le panier sur un site de commerce en ligne ou pour authentifier directement l'internaute. Ils sont nécessaires au bon fonctionnement d'un site Internet. Ils personnalisent également l'expérience de l'utilisateur sur un site Internet, en mémorisant ses préférences (sans consentement).
- Statistiques : pistent un utilisateur pour mesurer l'audience afin de réaliser des statistiques de fréquentation d'un site Internet.
- Internes : pour connaître votre comportement et proposer de la publicité ciblée
- Tierces parties : déposés par un site différent du site que vous visitez. Généralement utilisés par des régies publicitaires pour adapter l'affichage de leurs publicités, ou bien par les réseaux sociaux (Facebook par exemple)

## Que dit la loi sur l'utilisation des cookies ?

Ceux nécessaires au bon fonctionnement d'un site Internet ne nécessitent pas le consentement de l'utilisateur.
Ceux utilisés par les réseaux sociaux, ou à des fins publicitaires, doivent faire l'objet d'un consentement préalable de l'utilisateur. C'est le rôle des bandeaux affichés lors de l'ouverture d'un site Internet.
Il doit respecter les conditions du Règlement Général sur la Protection des Données (RGPD) : libre, spécifique, éclairé, univoque, et doit pouvoir être retiré à tout moment.

Certains sites proposent de payer un abonnement mensuel contre l'absence d'utilisation de cookies. Ce type de dispositif profite d'un flou juridique. La Commission Nationale Informatique et Liberté (CNIL) évalue au cas par cas la légalité de ces dispositifs.

## Puis-je paramétrer ou bloquer l'utilisation des cookies ?

Vous pouvez les paramétrer, voire les bloquer directement sur le navigateur Internet, ou encore par l'intermédiaire du bandeau proposé par les sites Internet.

### Depuis le navigateur Internet

Les navigateurs Internet permettent de paramétrer le pistage des sites Internet :

- Microsoft Edge : cliquez sur Paramètres > Cookies et autorisations de site > Gérer et supprimer les cookies et les données du site
- Google Chrome : cliquez sur Paramètres > Confidentialité et sécurité > Cookies et autres données des sites
- Mozilla Firefox : dans les Paramètres > Vie privée et sécurité > Protection renforcée contre le pistage, ainsi que Cookies et données de site

À SAVOIR

- Le paramétrage au niveau du navigateur bloque les cookies techniques nécessaires au bon fonctionnement des sites Internet : cette configuration doit être effectué avec prudence.
- La navigation en mode privée empêche le dépôt de cookies par le navigateur Internet, mais ne bloque pas forcément les autres moyens de pistage d’un site (pixel espion, collecte d’informations du navigateur…).
- Pour supprimer des cookies déjà déposés sur votre appareil, consultez le tutoriel à ce sujet : Supprimer les cookies sur les navigateurs Firefox, Chrome et Edge.

### Depuis le bandeau de connexion sur le site Internet

Les sites Internet qui les emploient à des fins de pistage sont dans l'obligation de proposer aux utilisateurs d'accepter, refuser ou paramétrer l'utilisation de ces cookies de manière consentie, libre, et éclairée.
Quand vous accédez à un site, n'hésitez pas à cliquer sur : Continuer sans accepter ou Refuser, placé en haut ou en bas du bandeau.
Sur notre exemple, l'indication se trouve en plus petit, en bas à gauche.

Si cette mention n'apparait pas, sélectionnez ceux que vous souhaitez autoriser ou bloquer en cliquant sur Personnaliser. En fonction des sites Internet, l'affichage des options de personnalisation peuvent varier.

##### Liens Utiles

Définition des cookies par la CNIL

Cookies et traceurs : que dit la loi ?

Payer pour éviter les cookies publicitaires, est-ce légal ?

##### Licence

Ce tutoriel est mis à disposition sous les termes de la Licence Ouverte 2.0 (ou cc by SA) Ce tutoriel a été produit dans le cadre du projet Solidarité Numérique. L’objectif est d’accompagner les citoyens dans leurs besoins numériques. Tous les éléments reproduits dans les captures d’écran sont la propriété des sites desquels ils sont tirés.

Dernière modification : 17 septembre 2021

Partager
Enregistrer / ImprimerEnregistrer

#### Les tutoriels sur la même thématique

##### Supprimer les cookies sur les navigateurs Firefox, Chrome, Edge

Internet

Dans certains cas, effacer les cookies de son navigateur est nécessaire. Ce tutoriel vous explique comment procéder.... lire la suite

##### Découvrir les principaux moteurs de recherche

Internet

Vous souhaitez en savoir plus sur les moteurs de recherche ? Ce panorama vous présente les principaux avec leurs spécificités.... lire la suite

##### Installer et utiliser Firefox sous Windows

Internet

Vous souhaitez changer de navigateur et utiliser Firefox ? Ce tutoriel vous détaille la procédure d'installation et la configuration pour une premi�... lire la suite

Voir plus

#### Les autres thématiques

Au quotidien
20 tutoriels

Vous recherchez de l'aide pour d'autres actions et démarches numériques du quotidien ? Ce dossier est fait pour vous ! Vous y trouverez des resso...... lire la suite

Communiquer
20 tutoriels

Vous souhaitez envoyer un email ou même réaliser un appel visio, mais vous ne savez pas comment vous y prendre ? Ce dossier vous donne les bases p...... lire la suite

Démarches administratives
22 tutoriels

Vous avez besoin d'aide pour vos démarches administratives ?
Vous trouverez dans ce dossier toutes les réponses pour réaliser vos opérat...... lire la suite

Education et formation
6 tutoriels

Vous rencontrez des difficultés à faire l'école à la maison pour vos enfants ? Ce dossier vous présente des ressources éducatives ainsi que d...... lire la suite

Premiers pas
33 tutoriels

Vous débutez dans votre apprentissage de l'informatique ?
Ce dossier est fait pour vous ! Vous y trouverez des ressources qui vous guideron...... lire la suite

Santé
15 tutoriels

Vous souhaitez prendre rendez-vous avec un professionnel de santé, mais les prises de rendez-vous en ligne ou les consultations à distance vous semb...... lire la suite